==> claromentis-framework-9.6.6-26891208.zip: web/intranet/common/classes/notification/NotificationAction.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] ?: array()) + array("_dcc103499ab6b46f861d4833f" . "6a2150b" => base64_decode("Q291bGRuJ3QgTG9hZCBQZXJt" . "aXNzaW9ucyBmb3Igc3Vic2Ny" . "aWJlZCBvYmplY3Q="), "_7f628626dd1d55c71b1fc0932ffd1d" . "2c" => base64_decode("aXNfYXJyYX" . "k="), "_4e1c7f6feb1b72e86f4dbea83a1741e" . "3" => base64_decode("V3JvbmcgcGFyYW1ldGVyICdTZW5kZXInIGZvc" . "iBub3RpZmljYXRpb24gb2JqZWN0IQ=="));
class NotificationAction extends ErrorHandler
{
    protected $sender;
    protected $event;
    protected $comment;
    protected $message_arg;
    protected $permitted_user_id_list;
    protected $message_code;
    protected $message_params;
    
    
    
    
    
    
    
    
    
    public function __construct($_44e986c04f41a08b56a383c7b3a88ee2 = null, $event = 0, $comment = 0, $_35533084fbc43d16244ada11e8c13d78 = 0)
    {
        if ($_44e986c04f41a08b56a383c7b3a88ee2) {
            $this->SetSender($_44e986c04f41a08b56a383c7b3a88ee2);
        }
        if ($event) {
            $this->SetEvent($event);
        }
        if ($_35533084fbc43d16244ada11e8c13d78) {
            $this->SetMessageArg($_35533084fbc43d16244ada11e8c13d78);
        }
        if ($comment) {
            $this->SetComment($comment);
        }
        $_75df4d581011f8631adf17a266cf8665 = array();
    }
    
    
    
    
    
    
    public function GetSender()
    {
        return $this->sender;
    }
    
    
    
    
    
    
    
    public function SetSender($_44e986c04f41a08b56a383c7b3a88ee2)
    {
        
        
        if (!$_44e986c04f41a08b56a383c7b3a88ee2 instanceof ClaAggregation) {
            throw new Exception($GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_4e1c7f6feb1b72e86f4dbea83" . "a1741e3"]);
        }
        $this->sender = $_44e986c04f41a08b56a383c7b3a88ee2;
        return true;
    }
    
    
    
    
    
    
    public function GetEvent()
    {
        return $this->event;
    }
    
    
    
    
    
    
    
    public function SetEvent($event)
    {
        $this->event = $event;
        return true;
    }
    
    
    
    
    
    
    public function GetComment()
    {
        return $this->comment;
    }
    
    
    
    
    
    
    
    public function SetComment($comment)
    {
        $this->comment = $comment;
        return true;
    }
    
    
    
    
    
    
    public function GetMessageParams()
    {
        if (!$this->message_params) {
            $this->message_params = $this->MakeMessageParams();
        }
        return $this->message_params;
    }
    
    
    
    
    
    
    public function MakeMessageParams()
    {
        return array();
    }
    
    
    
    
    
    
    public function GetMessageCode()
    {
        return $this->message_code;
    }
    
    
    
    
    
    
    public function GetMessageArg()
    {
        return $this->message_arg;
    }
    
    
    
    
    
    
    public function SetMessageArg($_35533084fbc43d16244ada11e8c13d78)
    {
        
        
        $this->message_arg = $_35533084fbc43d16244ada11e8c13d78;
        return true;
    }
    
    
    
    
    
    
    public function GetPermittedUserIds()
    {
        if (!$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_7f628626dd1d55" . "c71b1fc0932ffd1" . "d2c"]($this->permitted_user_id_list)) {
            if (!$this->LoadPerms()) {
                throw new Exception($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_dcc103499ab6b46f861d4833f6a2" . "150b"]);
            }
        }
        return $this->permitted_user_id_list;
    }
    
    
    
    
    
    public function LoadPerms()
    {
        
        
        $this->permitted_user_id_list = array();
        return true;
    }
    
    
    
    
    
    
    public function GetIMessageType()
    {
        
        
        return IMessage::TYPE_SYSTEM;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/common/classes/notification/NotificationAction.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] ?: array()) + array("_7f628626dd1d55c71b" . "1fc0932ffd1d2c" => base64_decode("aXNfY" . "XJyYX" . "k="), "_4e1c7f6feb1b72e8" . "6f4dbea83a1741e3" => base64_decode("V3JvbmcgcGFyYW1ldGVyICdTZW5kZXInIGZvciBub3RpZmljYXRpb24gb2JqZWN" . "0IQ=="), "_dcc103499ab6b46f861d4833f6a2" . "150b" => base64_decode("Q291bGRuJ3QgTG9hZCBQZXJtaXNzaW9ucyB" . "mb3Igc3Vic2NyaWJlZCBvYmplY3Q="));
class NotificationAction extends ErrorHandler
{
    protected $sender;
    protected $event;
    protected $comment;
    protected $message_arg;
    protected $permitted_user_id_list;
    protected $message_code;
    protected $message_params;
    
    
    
    
    
    
    
    
    
    public function __construct($_44e986c04f41a08b56a383c7b3a88ee2 = null, $event = 0, $comment = 0, $_35533084fbc43d16244ada11e8c13d78 = 0)
    {
        if ($_44e986c04f41a08b56a383c7b3a88ee2) {
            $this->SetSender($_44e986c04f41a08b56a383c7b3a88ee2);
        }
        if ($event) {
            $this->SetEvent($event);
        }
        if ($_35533084fbc43d16244ada11e8c13d78) {
            $this->SetMessageArg($_35533084fbc43d16244ada11e8c13d78);
        }
        if ($comment) {
            $this->SetComment($comment);
        }
        $_75df4d581011f8631adf17a266cf8665 = array();
    }
    
    
    
    
    
    
    public function GetSender()
    {
        return $this->sender;
    }
    
    
    
    
    
    
    
    public function SetSender($_44e986c04f41a08b56a383c7b3a88ee2)
    {
        
        
        if (!$_44e986c04f41a08b56a383c7b3a88ee2 instanceof ClaAggregation) {
            throw new Exception($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_4e1c7f6feb1b72e86f4dbea83" . "a1741e3"]);
        }
        $this->sender = $_44e986c04f41a08b56a383c7b3a88ee2;
        return true;
    }
    
    
    
    
    
    
    public function GetEvent()
    {
        return $this->event;
    }
    
    
    
    
    
    
    
    public function SetEvent($event)
    {
        $this->event = $event;
        return true;
    }
    
    
    
    
    
    
    public function GetComment()
    {
        return $this->comment;
    }
    
    
    
    
    
    
    
    public function SetComment($comment)
    {
        $this->comment = $comment;
        return true;
    }
    
    
    
    
    
    
    public function GetMessageParams()
    {
        if (!$this->message_params) {
            $this->message_params = $this->MakeMessageParams();
        }
        return $this->message_params;
    }
    
    
    
    
    
    
    public function MakeMessageParams()
    {
        return array();
    }
    
    
    
    
    
    
    public function GetMessageCode()
    {
        return $this->message_code;
    }
    
    
    
    
    
    
    public function GetMessageArg()
    {
        return $this->message_arg;
    }
    
    
    
    
    
    
    public function SetMessageArg($_35533084fbc43d16244ada11e8c13d78)
    {
        
        
        $this->message_arg = $_35533084fbc43d16244ada11e8c13d78;
        return true;
    }
    
    
    
    
    
    
    public function GetPermittedUserIds()
    {
        if (!$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_7f628626dd1d55c71b1" . "fc0932ffd1d2c"]($this->permitted_user_id_list)) {
            if (!$this->LoadPerms()) {
                throw new Exception($GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_dcc103499ab6b4" . "6f861d4833f6a21" . "50b"]);
            }
        }
        return $this->permitted_user_id_list;
    }
    
    
    
    
    
    public function LoadPerms()
    {
        
        
        $this->permitted_user_id_list = array();
        return true;
    }
    
    
    
    
    
    
    public function GetIMessageType()
    {
        
        
        return IMessage::TYPE_SYSTEM;
    }
}
